@@ -1,7 +1,7 @@
 U1.Clayton<-function(x.obs,y.obs,dx,dy,lower=0.001,upper=50,U.plot=TRUE){
     n=length(x.obs)
-
-    U.func=function(alpha){
+    
+    U.func=function(theta){
       u=0
       for(i in 1:(n-1)){
         xi=x.obs[i];yi=y.obs[i];dxi=dx[i];dyi=dy[i]
@@ -12,25 +12,26 @@ U1.Clayton<-function(x.obs,y.obs,dx,dy,lower=0.001,upper=50,U.plot=TRUE){
           if(Ox&Oy){
             xij=min(xi,xj);yij=min(yi,yj)
             Rij=sum( (x.obs>=xij)&(y.obs>=yij) )
-            Wij=(alpha+2)/(alpha+1)/(Rij+alpha)
-            u=u+Wij*(  ((xi-xj)*(yi-yj)>0)-(alpha+1)/(alpha+2)  )
+            Wij=(theta+2)/(theta+1)/(Rij+theta)
+            u=u+Wij*(  ((xi-xj)*(yi-yj)>0)-(theta+1)/(theta+2)  )
           }
         }
       }
       u
     }
-
-    if((U.func(lower)<0)&(U.func(upper)<0)){ alpha=lower }else{
-      alpha=uniroot(U.func,lower=lower,upper=upper)$root
+    
+    if((U.func(lower)<0)&(U.func(upper)<0)){ theta=lower }else{  
+      theta=uniroot(U.func,lower=lower,upper=upper)$root
     }
-    tau=alpha/(alpha+2)
-
-    if(U.plot==TRUE){
-      curve(U.func,lower,upper,xlab="alpha",ylab="U1(alpha)")
-      points(alpha,U.func(alpha),col="red",cex=1)
+    tau=theta/(theta+2)
+    
+    if(U.plot==TRUE){  
+      curve(U.func,lower,upper,xlab="theta",ylab="U1(theta)")
+      points(theta,U.func(theta),col="red",cex=1)
       abline(h=0,lty="dotted",col="blue")
     }
-
-    return(c(alpha=alpha,tau=tau))
+    
+    return(c(theta=theta,tau=tau))
 }
-
+  
+  
\ No newline at end of file
